@@ -6,6 +6,7 @@ DEVICE_TYPE_360_HEURIST = "276"
 DEVICE_TYPE_PURE_COOL_LINK = "475"
 DEVICE_TYPE_PURE_COOL_LINK_DESK = "469"
 DEVICE_TYPE_PURE_COOL = "438"
+DEVICE_TYPE_PURE_COOL_2021 = "438E"  # Not sure about the official name
 DEVICE_TYPE_PURE_COOL_DESK = "520"
 DEVICE_TYPE_PURE_HUMIDIFY_COOL = "358"
 DEVICE_TYPE_PURE_HOT_COOL_LINK = "455"
@@ -15,6 +16,7 @@ DEVICE_TYPE_NAMES = {
     DEVICE_TYPE_360_EYE: "360 Eye robot vacuum",
     DEVICE_TYPE_360_HEURIST: "360 Heurist robot vacuum",
     DEVICE_TYPE_PURE_COOL: "Pure Cool",
+    DEVICE_TYPE_PURE_COOL_2021: "Pure Cool (2021)",
     DEVICE_TYPE_PURE_COOL_DESK: "Pure Cool Desk",
     DEVICE_TYPE_PURE_COOL_LINK: "Pure Cool Link",
     DEVICE_TYPE_PURE_COOL_LINK_DESK: "Pure Cool Link Desk",
@@ -51,6 +53,7 @@ class HumidifyOscillationMode(Enum):
     DEGREE_45 = "0045"
     DEGREE_90 = "0090"
     BREEZE = "BRZE"
+    CUST = "CUST"
 
 
 class WaterHardness(Enum):
